@@ -21,25 +21,32 @@ from .literals import TypeType
 from .paginator import (
     ListDataSetRevisionsPaginator,
     ListDataSetsPaginator,
+    ListEventActionsPaginator,
     ListJobsPaginator,
     ListRevisionAssetsPaginator,
 )
 from .type_defs import (
+    ActionTypeDef,
     CreateDataSetResponseTypeDef,
+    CreateEventActionResponseTypeDef,
     CreateJobResponseTypeDef,
     CreateRevisionResponseTypeDef,
+    EventTypeDef,
     GetAssetResponseTypeDef,
     GetDataSetResponseTypeDef,
+    GetEventActionResponseTypeDef,
     GetJobResponseTypeDef,
     GetRevisionResponseTypeDef,
     ListDataSetRevisionsResponseTypeDef,
     ListDataSetsResponseTypeDef,
+    ListEventActionsResponseTypeDef,
     ListJobsResponseTypeDef,
     ListRevisionAssetsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     RequestDetailsTypeDef,
     UpdateAssetResponseTypeDef,
     UpdateDataSetResponseTypeDef,
+    UpdateEventActionResponseTypeDef,
     UpdateRevisionResponseTypeDef,
 )
 
@@ -73,7 +80,7 @@ class Exceptions:
 
 class DataExchangeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html)
     """
 
@@ -89,7 +96,7 @@ class DataExchangeClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#can_paginate)
         """
 
@@ -97,7 +104,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation cancels a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#cancel_job)
         """
 
@@ -112,17 +119,27 @@ class DataExchangeClient(BaseClient):
         """
         This operation creates a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.create_data_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.create_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_data_set)
         """
 
+    def create_event_action(
+        self, *, Action: "ActionTypeDef", Event: "EventTypeDef"
+    ) -> CreateEventActionResponseTypeDef:
+        """
+        This operation creates an event action.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.create_event_action)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_event_action)
+        """
+
     def create_job(
         self, *, Details: "RequestDetailsTypeDef", Type: TypeType
     ) -> CreateJobResponseTypeDef:
         """
         This operation creates a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.create_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.create_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_job)
         """
 
@@ -132,7 +149,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation creates a revision for a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.create_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.create_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_revision)
         """
 
@@ -140,7 +157,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation deletes an asset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.delete_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.delete_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_asset)
         """
 
@@ -148,15 +165,23 @@ class DataExchangeClient(BaseClient):
         """
         This operation deletes a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.delete_data_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.delete_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_data_set)
         """
 
+    def delete_event_action(self, *, EventActionId: str) -> None:
+        """
+        This operation deletes the event action.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.delete_event_action)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_event_action)
+        """
+
     def delete_revision(self, *, DataSetId: str, RevisionId: str) -> None:
         """
         This operation deletes a revision.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.delete_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.delete_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_revision)
         """
 
@@ -170,7 +195,7 @@ class DataExchangeClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#generate_presigned_url)
         """
 
@@ -180,7 +205,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation returns information about an asset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.get_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.get_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_asset)
         """
 
@@ -188,15 +213,23 @@ class DataExchangeClient(BaseClient):
         """
         This operation returns information about a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.get_data_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.get_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_data_set)
         """
 
+    def get_event_action(self, *, EventActionId: str) -> GetEventActionResponseTypeDef:
+        """
+        This operation retrieves information about an event action.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.get_event_action)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_event_action)
+        """
+
     def get_job(self, *, JobId: str) -> GetJobResponseTypeDef:
         """
         This operation returns information about a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.get_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.get_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_job)
         """
 
@@ -204,7 +237,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation returns information about a revision.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.get_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.get_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_revision)
         """
 
@@ -215,7 +248,7 @@ class DataExchangeClient(BaseClient):
         This operation lists a data set's revisions sorted by CreatedAt in descending
         order.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.list_data_set_revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.list_data_set_revisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_data_set_revisions)
         """
 
@@ -225,10 +258,20 @@ class DataExchangeClient(BaseClient):
         """
         This operation lists your data sets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.list_data_sets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.list_data_sets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_data_sets)
         """
 
+    def list_event_actions(
+        self, *, EventSourceId: str = ..., MaxResults: int = ..., NextToken: str = ...
+    ) -> ListEventActionsResponseTypeDef:
+        """
+        This operation lists your event actions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.list_event_actions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_event_actions)
+        """
+
     def list_jobs(
         self,
         *,
@@ -240,7 +283,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation lists your jobs sorted by CreatedAt in descending order.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_jobs)
         """
 
@@ -251,7 +294,7 @@ class DataExchangeClient(BaseClient):
         This operation lists a revision's assets sorted alphabetically in descending
         order.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.list_revision_assets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.list_revision_assets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_revision_assets)
         """
 
@@ -259,7 +302,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation lists the tags on the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_tags_for_resource)
         """
 
@@ -267,7 +310,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation starts a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.start_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.start_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#start_job)
         """
 
@@ -275,7 +318,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation tags a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#tag_resource)
         """
 
@@ -283,7 +326,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation removes one or more tags from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#untag_resource)
         """
 
@@ -293,7 +336,7 @@ class DataExchangeClient(BaseClient):
         """
         This operation updates an asset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.update_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.update_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_asset)
         """
 
@@ -303,17 +346,27 @@ class DataExchangeClient(BaseClient):
         """
         This operation updates a data set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.update_data_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.update_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_data_set)
         """
 
+    def update_event_action(
+        self, *, EventActionId: str, Action: "ActionTypeDef" = ...
+    ) -> UpdateEventActionResponseTypeDef:
+        """
+        This operation updates the event action.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.update_event_action)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_event_action)
+        """
+
     def update_revision(
         self, *, DataSetId: str, RevisionId: str, Comment: str = ..., Finalized: bool = ...
     ) -> UpdateRevisionResponseTypeDef:
         """
         This operation updates a revision.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Client.update_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Client.update_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_revision)
         """
 
@@ -322,21 +375,30 @@ class DataExchangeClient(BaseClient):
         self, operation_name: Literal["list_data_set_revisions"]
     ) -> ListDataSetRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listdatasetrevisionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_data_sets"]) -> ListDataSetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listdatasetspaginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_event_actions"]
+    ) -> ListEventActionsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Paginator.ListEventActions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listeventactionspaginator)
+        """
+
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listjobspaginator)
         """
 
@@ -345,6 +407,6 @@ class DataExchangeClient(BaseClient):
         self, operation_name: Literal["list_revision_assets"]
     ) -> ListRevisionAssetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listrevisionassetspaginator)
         """
