@@ -26,6 +26,7 @@ __all__ = (
     "JobErrorResourceTypesType",
     "ListDataSetRevisionsPaginatorName",
     "ListDataSetsPaginatorName",
+    "ListEventActionsPaginatorName",
     "ListJobsPaginatorName",
     "ListRevisionAssetsPaginatorName",
     "OriginType",
@@ -48,9 +49,10 @@ CodeType = Literal[
     "VALIDATION_EXCEPTION",
 ]
 JobErrorLimitNameType = Literal["Asset size in GB", "Assets per revision"]
-JobErrorResourceTypesType = Literal["ASSET", "REVISION"]
+JobErrorResourceTypesType = Literal["ASSET", "DATA_SET", "REVISION"]
 ListDataSetRevisionsPaginatorName = Literal["list_data_set_revisions"]
 ListDataSetsPaginatorName = Literal["list_data_sets"]
+ListEventActionsPaginatorName = Literal["list_event_actions"]
 ListJobsPaginatorName = Literal["list_jobs"]
 ListRevisionAssetsPaginatorName = Literal["list_revision_assets"]
 OriginType = Literal["ENTITLED", "OWNED"]
@@ -65,6 +67,7 @@ TypeType = Literal[
 ]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -97,6 +100,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
@@ -347,5 +351,9 @@ ServiceName = Literal[
     "xray",
 ]
 PaginatorName = Literal[
-    "list_data_set_revisions", "list_data_sets", "list_jobs", "list_revision_assets"
+    "list_data_set_revisions",
+    "list_data_sets",
+    "list_event_actions",
+    "list_jobs",
+    "list_revision_assets",
 ]
